package com.evobms.project.bms.service.impl;

import java.util.List;
import com.evobms.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.evobms.project.bms.mapper.BmsSystemStatusMapper;
import com.evobms.project.bms.domain.BmsSystemStatus;
import com.evobms.project.bms.service.IBmsSystemStatusService;

/**
 * BMS系统状态数据Service业务层处理
 * 
 * @author tzy
 * @date 2026-02-23
 */
@Service
public class BmsSystemStatusServiceImpl extends ServiceImpl<BmsSystemStatusMapper, BmsSystemStatus> implements IBmsSystemStatusService 
{
    @Autowired
    private BmsSystemStatusMapper bmsSystemStatusMapper;

    /**
     * 查询BMS系统状态数据
     * 
     * @param id BMS系统状态数据主键
     * @return BMS系统状态数据
     */
    @Override
    public BmsSystemStatus selectBmsSystemStatusById(Long id)
    {
        return bmsSystemStatusMapper.selectBmsSystemStatusById(id);
    }

    /**
     * 查询BMS系统状态数据列表
     * 
     * @param bmsSystemStatus BMS系统状态数据
     * @return BMS系统状态数据
     */
    @Override
    public List<BmsSystemStatus> selectBmsSystemStatusList(BmsSystemStatus bmsSystemStatus)
    {
        return bmsSystemStatusMapper.selectBmsSystemStatusList(bmsSystemStatus);
    }

    /**
     * 新增BMS系统状态数据
     * 
     * @param bmsSystemStatus BMS系统状态数据
     * @return 结果
     */
    @Override
    public int insertBmsSystemStatus(BmsSystemStatus bmsSystemStatus)
    {
        bmsSystemStatus.setCreateTime(DateUtils.getNowDate());
        return bmsSystemStatusMapper.insertBmsSystemStatus(bmsSystemStatus);
    }

    /**
     * 修改BMS系统状态数据
     * 
     * @param bmsSystemStatus BMS系统状态数据
     * @return 结果
     */
    @Override
    public int updateBmsSystemStatus(BmsSystemStatus bmsSystemStatus)
    {
        bmsSystemStatus.setUpdateTime(DateUtils.getNowDate());
        return bmsSystemStatusMapper.updateBmsSystemStatus(bmsSystemStatus);
    }

    /**
     * 批量删除BMS系统状态数据
     * 
     * @param ids 需要删除的BMS系统状态数据主键
     * @return 结果
     */
    @Override
    public int deleteBmsSystemStatusByIds(Long[] ids)
    {
        return bmsSystemStatusMapper.deleteBmsSystemStatusByIds(ids);
    }

    /**
     * 删除BMS系统状态数据信息
     * 
     * @param id BMS系统状态数据主键
     * @return 结果
     */
    @Override
    public int deleteBmsSystemStatusById(Long id)
    {
        return bmsSystemStatusMapper.deleteBmsSystemStatusById(id);
    }
}
