package com.evobms.project.bms.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.evobms.framework.aspectj.lang.annotation.Log;
import com.evobms.framework.aspectj.lang.enums.BusinessType;
import com.evobms.project.bms.domain.BmsSystemStatus;
import com.evobms.project.bms.service.IBmsSystemStatusService;
import com.evobms.framework.web.controller.BaseController;
import com.evobms.framework.web.domain.AjaxResult;
import com.evobms.common.utils.poi.ExcelUtil;
import com.evobms.framework.web.page.TableDataInfo;

/**
 * BMS系统状态数据Controller
 *
 * @author tzy
 * @date 2026-02-23
 */
@RestController
@RequestMapping("/bms/systemstatus/data")
public class BmsSystemStatusController extends BaseController
{
    @Autowired
    private IBmsSystemStatusService bmsSystemStatusService;

    /**
     * 查询BMS系统状态数据列表
     */
    @PreAuthorize("@ss.hasPermi('bms:data:list')")
    @GetMapping("/list")
    public TableDataInfo list(BmsSystemStatus bmsSystemStatus)
    {
        startPage();
        List<BmsSystemStatus> list = bmsSystemStatusService.selectBmsSystemStatusList(bmsSystemStatus);
        return getDataTable(list);
    }

    /**
     * 导出BMS系统状态数据列表
     */
    @PreAuthorize("@ss.hasPermi('bms:data:export')")
    @Log(title = "BMS系统状态数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BmsSystemStatus bmsSystemStatus)
    {
        List<BmsSystemStatus> list = bmsSystemStatusService.selectBmsSystemStatusList(bmsSystemStatus);
        ExcelUtil<BmsSystemStatus> util = new ExcelUtil<BmsSystemStatus>(BmsSystemStatus.class);
        util.exportExcel(response, list, "BMS系统状态数据数据");
    }

    /**
     * 获取BMS系统状态数据详细信息
     */
    @PreAuthorize("@ss.hasPermi('bms:data:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(bmsSystemStatusService.selectBmsSystemStatusById(id));
    }

    /**
     * 新增BMS系统状态数据
     */
    @PreAuthorize("@ss.hasPermi('bms:data:add')")
    @Log(title = "BMS系统状态数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BmsSystemStatus bmsSystemStatus)
    {
        return toAjax(bmsSystemStatusService.insertBmsSystemStatus(bmsSystemStatus));
    }

    /**
     * 修改BMS系统状态数据
     */
    @PreAuthorize("@ss.hasPermi('bms:data:edit')")
    @Log(title = "BMS系统状态数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BmsSystemStatus bmsSystemStatus)
    {
        return toAjax(bmsSystemStatusService.updateBmsSystemStatus(bmsSystemStatus));
    }

    /**
     * 删除BMS系统状态数据
     */
    @PreAuthorize("@ss.hasPermi('bms:data:remove')")
    @Log(title = "BMS系统状态数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(bmsSystemStatusService.deleteBmsSystemStatusByIds(ids));
    }
}
